/*
 Photo Wizard
 A batch image convertor that performs simple image processing tasks.
 Copyright  2004, Manas Tungare.
 --------------------------------------------------------------------------
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
using System;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Windows.Forms;
using System.Text;

namespace Org.ManasTungare.PhotoWizard.Operations
{
	/// <summary>
	/// Increase or decrease contrast of the image.
	/// </summary>
	public class Contrast : System.Windows.Forms.UserControl, Org.ManasTungare.PhotoWizard.IOperation
	{
		private System.Windows.Forms.GroupBox contrastGroupBox;
		private System.Windows.Forms.CheckBox enableContrastCheckBox;
		private System.Windows.Forms.TrackBar contrastTrackBar;
		/// <summary> 
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;

		public Contrast()
		{
			// This call is required by the Windows.Forms Form Designer.
			InitializeComponent();
		}

		/// <summary> 
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Component Designer generated code
		/// <summary> 
		/// Required method for Designer support - do not modify 
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.contrastGroupBox = new System.Windows.Forms.GroupBox();
			this.contrastTrackBar = new System.Windows.Forms.TrackBar();
			this.enableContrastCheckBox = new System.Windows.Forms.CheckBox();
			this.contrastGroupBox.SuspendLayout();
			((System.ComponentModel.ISupportInitialize)(this.contrastTrackBar)).BeginInit();
			this.SuspendLayout();
			// 
			// contrastGroupBox
			// 
			this.contrastGroupBox.Controls.Add(this.contrastTrackBar);
			this.contrastGroupBox.Controls.Add(this.enableContrastCheckBox);
			this.contrastGroupBox.Dock = System.Windows.Forms.DockStyle.Fill;
			this.contrastGroupBox.Location = new System.Drawing.Point(0, 0);
			this.contrastGroupBox.Name = "contrastGroupBox";
			this.contrastGroupBox.Size = new System.Drawing.Size(288, 88);
			this.contrastGroupBox.TabIndex = 0;
			this.contrastGroupBox.TabStop = false;
			// 
			// contrastTrackBar
			// 
			this.contrastTrackBar.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left) 
				| System.Windows.Forms.AnchorStyles.Right)));
			this.contrastTrackBar.Enabled = false;
			this.contrastTrackBar.LargeChange = 1;
			this.contrastTrackBar.Location = new System.Drawing.Point(32, 43);
			this.contrastTrackBar.Name = "contrastTrackBar";
			this.contrastTrackBar.Size = new System.Drawing.Size(240, 42);
			this.contrastTrackBar.TabIndex = 1;
			this.contrastTrackBar.Value = 5;
			// 
			// enableContrastCheckBox
			// 
			this.enableContrastCheckBox.Font = new System.Drawing.Font("Tahoma", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.enableContrastCheckBox.Location = new System.Drawing.Point(16, 16);
			this.enableContrastCheckBox.Name = "enableContrastCheckBox";
			this.enableContrastCheckBox.Size = new System.Drawing.Size(88, 24);
			this.enableContrastCheckBox.TabIndex = 0;
			this.enableContrastCheckBox.Text = "Contrast";
			this.enableContrastCheckBox.CheckedChanged += new System.EventHandler(this.enableContrastCheckBox_CheckedChanged);
			// 
			// Contrast
			// 
			this.AutoScroll = true;
			this.AutoScrollMinSize = new System.Drawing.Size(236, 88);
			this.Controls.Add(this.contrastGroupBox);
			this.Font = new System.Drawing.Font("Tahoma", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.Name = "Contrast";
			this.Size = new System.Drawing.Size(288, 88);
			this.contrastGroupBox.ResumeLayout(false);
			((System.ComponentModel.ISupportInitialize)(this.contrastTrackBar)).EndInit();
			this.ResumeLayout(false);

		}
		#endregion

		public string getImageMagickCommand() 
		{
			StringBuilder output = new StringBuilder();
			int contrastCount = this.contrastTrackBar.Value - (this.contrastTrackBar.Maximum / 2);

			for (int numCommands = 0; numCommands < Math.Abs(contrastCount); numCommands++) 
			{
				output.Append( contrastCount > 0 ? "-" : "+" );
				output.Append( "contrast " );
			}
			return this.enableContrastCheckBox.Checked ? output.ToString() : "";
		}

		private void enableContrastCheckBox_CheckedChanged(object sender, System.EventArgs e)
		{
			this.contrastTrackBar.Enabled = this.enableContrastCheckBox.Checked;
		}

	}
}
