/*
 Photo Wizard
 A batch image convertor that performs simple image processing tasks.
 Copyright  2004, Manas Tungare.
 --------------------------------------------------------------------------
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;

namespace Org.ManasTungare.PhotoWizard
{
	/// <summary>
	/// A status window that is shown above the main window when an image
	/// processing task is in progress.
	/// </summary>
	public class StatusWindow : System.Windows.Forms.Form
	{
		private System.Windows.Forms.Label processingLabel;
		private System.Windows.Forms.Label currentFile;
		private System.Windows.Forms.Button cancelButton;
		private System.Windows.Forms.Label currentFileLabel;
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;
		private bool _cancelPressed = false;

		public StatusWindow()
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.processingLabel = new System.Windows.Forms.Label();
			this.currentFileLabel = new System.Windows.Forms.Label();
			this.currentFile = new System.Windows.Forms.Label();
			this.cancelButton = new System.Windows.Forms.Button();
			this.SuspendLayout();
			// 
			// processingLabel
			// 
			this.processingLabel.AutoSize = true;
			this.processingLabel.Location = new System.Drawing.Point(16, 16);
			this.processingLabel.Name = "processingLabel";
			this.processingLabel.Size = new System.Drawing.Size(61, 17);
			this.processingLabel.TabIndex = 0;
			this.processingLabel.Text = "Processing:";
			// 
			// currentFileLabel
			// 
			this.currentFileLabel.Location = new System.Drawing.Point(16, 64);
			this.currentFileLabel.Name = "currentFileLabel";
			this.currentFileLabel.Size = new System.Drawing.Size(424, 16);
			this.currentFileLabel.TabIndex = 1;
			this.currentFileLabel.Text = "...";
			// 
			// currentFile
			// 
			this.currentFile.AutoSize = true;
			this.currentFile.Location = new System.Drawing.Point(16, 48);
			this.currentFile.Name = "currentFile";
			this.currentFile.Size = new System.Drawing.Size(66, 17);
			this.currentFile.TabIndex = 2;
			this.currentFile.Text = "Current File:";
			// 
			// cancelButton
			// 
			this.cancelButton.DialogResult = System.Windows.Forms.DialogResult.Cancel;
			this.cancelButton.Location = new System.Drawing.Point(352, 96);
			this.cancelButton.Name = "cancelButton";
			this.cancelButton.Size = new System.Drawing.Size(88, 24);
			this.cancelButton.TabIndex = 3;
			this.cancelButton.Text = "&Cancel";
			this.cancelButton.Click += new System.EventHandler(this.cancelButton_Click);
			// 
			// StatusWindow
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 14);
			this.CancelButton = this.cancelButton;
			this.ClientSize = new System.Drawing.Size(458, 135);
			this.ControlBox = false;
			this.Controls.Add(this.cancelButton);
			this.Controls.Add(this.currentFile);
			this.Controls.Add(this.processingLabel);
			this.Controls.Add(this.currentFileLabel);
			this.Font = new System.Drawing.Font("Tahoma", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedDialog;
			this.MaximizeBox = false;
			this.MinimizeBox = false;
			this.Name = "StatusWindow";
			this.ShowInTaskbar = false;
			this.StartPosition = System.Windows.Forms.FormStartPosition.CenterParent;
			this.Text = "Processing Status";
			this.TopMost = true;
			this.ResumeLayout(false);

		}
		#endregion

		private void cancelButton_Click(object sender, System.EventArgs e)
		{
			_cancelPressed = true;
		}

		public string CurrentFile 
		{
			get 
			{
				return this.currentFileLabel.Text;
			}
			set 
			{
				this.currentFileLabel.Text = value;
			}
		}

		public string StatusMessage 
		{
			get 
			{
				return this.processingLabel.Text;
			}
			set 
			{
				this.processingLabel.Text = value;
			}
		}

		public bool CancelPressed
		{
			get 
			{
				return _cancelPressed;
			}
		}
	}
}
